@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,14 +28,14 @@ class SieveConditionSize : public SieveCondition
 public:
     explicit SieveConditionSize(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
 
-    QWidget *createParamWidget(QWidget *parent) const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
 
-    QString code(QWidget *parent) const override;
+    Q_REQUIRED_RESULT QString code(QWidget *parent) const override;
 
-    QString help() const override;
+    Q_REQUIRED_RESULT QString help() const override;
 
-    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, bool notCondition, QString &error) override;
-    QUrl href() const override;
+    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, bool notCondition, QString &error) override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
 
